==> seplib-6.3.5.tar.gz: seplib-6.3.5/seplib_base/lib/corelibs/superset/sect_io.c <==
#define SET_SDOC 1
#include<sitedef.h>
#include<math.h>
#include<superset.h>
#include<../include/superset_internal.h>


int SEPDFF_open_local_tags(sep_dff *info, int nsect, int *sect_list,sep_3d **info_part){
char usage[1024];
int isect;

for(isect=0; isect < nsect; isect++){
  auxinout(info->tag_sect[sect_list[isect]]);
  info_part[isect]=tag_info_sep3d(info->tag_sect[sect_list[isect]], INQUIRE);  
   if(info_part[isect] == SEPNULL)
  return (sepwarn(INVALID_STRUC,"sect problem tag:%s \n",
    info->tag_sect[sect_list[isect]]));
}

return(SUCCESS);
}

int SEP3D_convert_window_1(sep_3d *info, int isect, int nwind, int fwind, 
  int jwind,int *nsave,int *fsave,int *jsave,int *axis_map){
int idim;
int skip,beg,end,last,e;
int i,iglobal,ilocal,ifirst,ilast,ic;
sep_3d *info_local;

  if(info->dff==SEPNULL) 
    return(sepwarn(NOT_MET,"can't convert window for non-sectioned tag \n",
     info->name));


  info_local=tag_info_sep3d(info->dff->tag_sect[isect], INQUIRE);  
 if(info_local == SEPNULL)
  return(sepwarn(INVALID_STRUC,"sect problem tag:%s \n",
     info->dff->tag_sect[isect]));



  if(info->dff->sect_axis!=1){
    *nsave=nwind; *fsave=fwind; *jsave=jwind;
  }
  else{
    beg=floor((double)(info_local->o[0]-
     info->o[0])/((double)info->d[0])+.5);
    end=floor((double)(info_local->o[0]+info_local->d[0]*
     (info_local->n[0]-1)-info->o[0])/((double)info->d[0])+.5);
    last=fwind+jwind*(nwind-1); 
    skip=floor((double)info_local->d[0]/((double)info->d[0])+.5);
    ifirst=info->nwind[0]; ilast=-1;
    ic=0;
    for(i=0; i < nwind; i++){ /*loop through desiered window*/
      iglobal=fwind+jwind*i;
      if((iglobal-beg)%skip==0){
        ilocal=(iglobal-beg)/skip;
        axis_map[ilocal]=iglobal;
        if(ilocal < ifirst) ifirst=ilocal;
        if(ilocal> ilast) ilast=ilocal;
        ic+=1;
      }
    }
    *fsave=ifirst;
    *jsave=jwind*skip;
    *nsave=ic;
  }

return(SUCCESS); 
}

int SEP3D_convert_window_2(sep_3d *info, int isect, int *nwind, int *fwind, 
  int *jwind,int *nsave,int *fsave,int *jsave){
int idim;
int skip,beg,end,last,e;
int i,iglobal,ilocal,ifirst,ilast,ic;
sep_3d *info_local;

  if(info->dff==SEPNULL) return(sepwarn(NOT_MET,
    "can't convert a non-sectioned tag %s \n",info->name));

  info_local=tag_info_sep3d(info->dff->tag_sect[isect], INQUIRE);  
 if(info_local == SEPNULL)
  return(sepwarn(INVALID_STRUC,"sect problem tag:%s \n",
    info->dff->tag_sect[isect]));


for(idim=1; idim< info->ndims; idim++){ 
  if(info->dff->sect_axis!=idim+1){
    nsave[idim]=nwind[idim]; fsave[idim]=fwind[idim]; jsave[idim]=jwind[idim];
  }
  else{
    beg=floor((double)(info_local->o[idim]-
     info->o[idim])/((double)info->d[idim])+.5);
    end=floor((double)(info_local->o[idim]+info_local->d[idim]*
     (info_local->n[idim]-1)-info->o[idim])/((double)info->d[idim])+.5);
    last=fwind[idim]+jwind[idim]*(nwind[idim]-1); 
    skip=floor((double)info_local->d[idim]/((double)info->d[idim])+.5);
    ifirst=info->nwind[idim]; ilast=-1;
    jsave[idim]=skip*jwind[idim];ic=0;
    for(i=0; i < nwind[idim]; i++){ /*loop through desiered window*/
      iglobal=fwind[idim]+jwind[idim]*i;
      if((iglobal-beg)%skip==0){
        ilocal=(iglobal-beg)/skip;
        if(ilocal < ifirst) ifirst=ilocal;
        if(ilocal> ilast) ilast=ilocal;
        ic+=1;
      }
    }
    fsave[idim]=ifirst;
    jsave[idim]=jwind[idim]*skip;
    nsave[idim]=ic;
  }
}

return(SUCCESS); 
}
int sep3d_write_dff(char *tag, char *sep3dname){
sep_3d *info;
char headername[512],temp_ch[2048],temp2_ch[1024];
char dff_tag[512];
int i;


 info=tag_info_sep3d(sep3dname, INQUIRE);  

 if(info == SEPNULL)
  return(sepwarn(INVALID_STRUC,"tag problem write_dff %s \n",sep3dname));


 if(info->dff == SEPNULL){
   auxputch("dff","s","-1",tag);
   if(0!=sep_put_distrib_format_tag(tag,"-1"))
     return(sepwarn(NOT_MET,"trouble setting distribute tag to null \n"));
   return(SUCCESS);
 }

   
 if(0!=fget_distrib_format_tag(tag,dff_tag))
   return(sepwarn(NOT_MET,"trouble getting distribution format tag for %s \n",
    dff_tag));

 if(0!=SEPDFF_to_dff(info->dff, dff_tag))
   return(sepwarn(NOT_MET,"trouble writing out distribution tag %s \n",
    dff_tag));

  return(SUCCESS);
}

==> seplib-6.3.8.tar.gz: seplib-6.3.8/seplib_base/lib/corelibs/superset/sect_io.c <==
#define SET_SDOC 1
#include<sitedef.h>
#include<math.h>
#include<superset.h>
#include<superset_internal.h>


int SEPDFF_open_local_tags(sep_dff *info, int nsect, int *sect_list,sep_3d **info_part){
char usage[1024],temp_name[2049];
int isect;

for(isect=0; isect < nsect; isect++){
  auxinout(info->tag_sect[sect_list[isect]]);
  SEPDFF_sect_name(info,isect,temp_name);
  info_part[isect]=tag_info_section(info,sect_list[isect], INQUIRE);  
   if(info_part[isect] == SEPNULL)
  return (sepwarn(INVALID_STRUC,"sect problem tag:%s \n",
    info->tag_sect[sect_list[isect]]));
}

return(SUCCESS);
}

int SEP3D_convert_window_1(sep_3d *info, int isect, int nwind, int fwind, 
  int jwind,int *nsave,int *fsave,int *jsave,int *axis_map){
int idim;
int skip,beg,end,last,e;
int i,iglobal,ilocal,ifirst,ilast,ic;
sep_3d *info_local;

  if(info->dff==SEPNULL) 
    return(sepwarn(NOT_MET,"can't convert window for non-sectioned tag \n",
     info->name));


  info_local=tag_info_section(info->dff,isect, INQUIRE);  
 if(info_local == SEPNULL)
  return(sepwarn(INVALID_STRUC,"sect problem tag:%s \n",
     info->dff->tag_sect[isect]));



  if(info->dff->sect_axis!=1){
    *nsave=nwind; *fsave=fwind; *jsave=jwind;
  }
  else{
    beg=floor((double)(info_local->o[0]-
     info->o[0])/((double)info->d[0])+.5);
    end=floor((double)(info_local->o[0]+info_local->d[0]*
     (info_local->n[0]-1)-info->o[0])/((double)info->d[0])+.5);
    last=fwind+jwind*(nwind-1); 
    skip=floor((double)info_local->d[0]/((double)info->d[0])+.5);
    ifirst=info->nwind[0]; ilast=-1;
    ic=0;
    for(i=0; i < nwind; i++){ /*loop through desiered window*/
      iglobal=fwind+jwind*i;
      if((iglobal-beg)%skip==0){
        ilocal=(iglobal-beg)/skip;
        axis_map[ilocal]=iglobal;
        if(ilocal < ifirst) ifirst=ilocal;
        if(ilocal> ilast) ilast=ilocal;
        ic+=1;
      }
    }
    *fsave=ifirst;
    *jsave=jwind*skip;
    *nsave=ic;
  }

return(SUCCESS); 
}

int SEP3D_convert_window_2(sep_3d *info, int isect, int *nwind, int *fwind, 
  int *jwind,int *nsave,int *fsave,int *jsave){
int idim;
int skip,beg,end,last,e;
int i,iglobal,ilocal,ifirst,ilast,ic;
sep_3d *info_local;

  if(info->dff==SEPNULL) return(sepwarn(NOT_MET,
    "can't convert a non-sectioned tag %s \n",info->name));

  info_local=tag_info_section(info->dff,isect, INQUIRE);  
 if(info_local == SEPNULL)
  return(sepwarn(INVALID_STRUC,"sect problem tag:%s \n",
    info->dff->tag_sect[isect]));


for(idim=1; idim< info->ndims; idim++){ 
  if(info->dff->sect_axis!=idim+1){
    nsave[idim]=nwind[idim]; fsave[idim]=fwind[idim]; jsave[idim]=jwind[idim];
  }
  else{
    beg=floor((double)(info_local->o[idim]-
     info->o[idim])/((double)info->d[idim])+.5);
    end=floor((double)(info_local->o[idim]+info_local->d[idim]*
     (info_local->n[idim]-1)-info->o[idim])/((double)info->d[idim])+.5);
    last=fwind[idim]+jwind[idim]*(nwind[idim]-1); 
    skip=floor((double)info_local->d[idim]/((double)info->d[idim])+.5);
    ifirst=info->nwind[idim]; ilast=-1;
    jsave[idim]=skip*jwind[idim];ic=0;
    for(i=0; i < nwind[idim]; i++){ /*loop through desiered window*/
      iglobal=fwind[idim]+jwind[idim]*i;
      if((iglobal-beg)%skip==0){
        ilocal=(iglobal-beg)/skip;
        if(ilocal < ifirst) ifirst=ilocal;
        if(ilocal> ilast) ilast=ilocal;
        ic+=1;
      }
    }
    fsave[idim]=ifirst;
    jsave[idim]=jwind[idim]*skip;
    nsave[idim]=ic;
  }
}

return(SUCCESS); 
}
int sep3d_write_dff(char *tag, char *sep3dname){
sep_3d *info;
char headername[512],temp_ch[2048],temp2_ch[1024];
char dff_tag[512];
int i;


 info=tag_info_sep3d(sep3dname, INQUIRE);  

 if(info == SEPNULL)
  return(sepwarn(INVALID_STRUC,"tag problem write_dff %s \n",sep3dname));


 if(info->dff == SEPNULL){
   auxputch("dff","s","-1",tag);
   if(0!=sep_put_distrib_format_tag(tag,"-1"))
     return(sepwarn(NOT_MET,"trouble setting distribute tag to null \n"));
   return(SUCCESS);
 }

   
 if(0!=fget_distrib_format_tag(tag,dff_tag))
   return(sepwarn(NOT_MET,"trouble getting distribution format tag for %s \n",
    dff_tag));

 if(0!=SEPDFF_to_dff(info->dff, dff_tag))
   return(sepwarn(NOT_MET,"trouble writing out distribution tag %s \n",
    dff_tag));

  return(SUCCESS);
}
